@@ -30,16 +30,6 @@ class BaseSilverIngestionService(ABC):
 
 
 class BaseSilverIngestionServiceImpl(BaseSilverIngestionService, ABC):
-    """TODO:
-    1. validate parameters hier rein
-        - dann muss man nur seine eigenen validieren
-    2. InsertOnly base impl
-    3. InsertOnly base testen
-    4. SCD2 base impl
-    5. SCD2 base tests schreiben
-    6. SCD2 base testen
-
-    """
     _is_initialized: bool = False
 
     @abstractmethod
@@ -208,6 +198,12 @@ class BaseSilverIngestionServiceImpl(BaseSilverIngestionService, ABC):
 
         writer.saveAsTable(self._dest_table.table_path)
 
+    def _create_destination_schema(self) -> None:
+        """Creates the destination schema if it does not exist."""
+        sql = f"CREATE SCHEMA IF NOT EXISTS {self._dest_table.lakehouse}.{self._dest_table.schema}"
+        if not self._is_testing_mock:
+            self._spark.sql(sql)
+
     def _get_columns_ordered(self, df: DataFrame, last_columns: list[str]) -> list[str]:
         """Get the columns in the desired order for processing.
 
